import type { JSONSchema7 } from 'json-schema';
import type { NangoModel, NangoModelField, NangoYamlParsed } from '@nangohq/types';
import type { ServiceResponse } from '@nangohq/shared';
export type ModelsMap = Map<string, Record<string, any>>;
/**
 * Load nango.yaml and generate model.ts
 */
export declare function loadYamlAndGenerate({ fullPath, debug }: {
    fullPath: string;
    debug?: boolean;
}): ServiceResponse<NangoYamlParsed>;
export declare function loadSchemaJson({ fullPath }: {
    fullPath: string;
}): JSONSchema7 | null;
/**
 * Build models.ts
 */
export declare function buildModelsTS({ parsed }: {
    parsed: NangoYamlParsed;
}): string;
export declare function generateInterfaces({ parsed }: {
    parsed: NangoYamlParsed;
}): string[];
/**
 * Transform a JSON model to its Typescript equivalent
 */
export declare function modelToTypescript({ model }: {
    model: NangoModel;
}): string;
export declare function fieldsToTypescript({ fields }: {
    fields: NangoModelField[];
}): string[];
/**
 * Transform a field definition to its typescript equivalent
 */
export declare function fieldToTypescript({ field }: {
    field: NangoModelField;
}): string | boolean | null | undefined | number;
/**
 * Generate SDK types
 */
export declare function generateSDKTypes(): string;
export declare function generateAdditionalExports({ fullPath, parsed, debug }: {
    fullPath: string;
    parsed: NangoYamlParsed;
    debug: boolean;
}): void;
export declare function getExportToTS({ parsed }: {
    parsed: NangoYamlParsed;
}): string;
export declare function getExportToJSON({ pathTS }: {
    pathTS: string;
}): JSONSchema7;
