import fs from 'node:fs';
import path from 'node:path';
export function ensureDirectoryExists(directoryName) {
    if (!fs.existsSync(directoryName)) {
        fs.mkdirSync(directoryName, { recursive: true });
    }
}
function saveResponse({ directoryName, data, customFilePath, concatenateIfExists }) {
    ensureDirectoryExists(`${directoryName}/mocks`);
    const filePath = path.join(directoryName, customFilePath);
    ensureDirectoryExists(path.dirname(filePath));
    if (fs.existsSync(filePath)) {
        const existingData = JSON.parse(fs.readFileSync(filePath, 'utf8'));
        if (concatenateIfExists && Array.isArray(existingData) && Array.isArray(data)) {
            data = data.concat(existingData);
        }
    }
    fs.writeFileSync(filePath, JSON.stringify(data, null, 2));
}
export function onAxiosRequestFulfilled({ response, providerConfigKey, connectionId, syncName }) {
    if (!providerConfigKey) {
        return response;
    }
    const directoryName = `${process.env['NANGO_MOCKS_RESPONSE_DIRECTORY'] ?? ''}${providerConfigKey}`;
    const method = response.config.method?.toLowerCase() || 'get';
    if (response.request.path.includes(`/connection/${connectionId}?provider_config_key=${providerConfigKey}`)) {
        const connection = response.data;
        // getConnection could be getMetadata as well which would be cached
        saveResponse({
            directoryName,
            data: { metadata: connection.metadata, connection_config: connection.connection_config },
            customFilePath: 'mocks/nango/getConnection.json',
            concatenateIfExists: false
        });
        saveResponse({
            directoryName,
            data: connection.metadata,
            customFilePath: 'mocks/nango/getMetadata.json',
            concatenateIfExists: false
        });
        return response;
    }
    const [pathname, params] = response.request.path.split('?');
    const strippedPath = pathname.replace('/', '');
    let concatenateIfExists = false;
    if (params && params.includes('page')) {
        concatenateIfExists = true;
    }
    saveResponse({
        directoryName,
        data: response.data,
        customFilePath: `mocks/nango/${method}/${strippedPath}/${syncName}.json`,
        concatenateIfExists
    });
    return response;
}
//# sourceMappingURL=response-saver.service.js.map